  function MakeNF1()
% Graphically depicts Newton's method in the complex plane
% as it tries to find a zero of f(z) = z^4 -1;
i = sqrt(-1);
close all
figure
% Maximum number of Newton steps...
MaxSteps = 50;
% The display area has center (xc,yc) and side length 2R
xc = 0; yc = 0; r = 6;
axis([xc-r xc+r yc-r yc+r])
fill([xc-r xc+r xc+r xc-r],[yc-r yc-r yc+r yc+r],'k')
hold on
% Display the 45 degree lines...
plot([xc-r xc+r],[yc-r yc+r],'y',[xc-r xc+r],[yc+r yc-r],'y');
axis square 
set(gcf,'position',[100 100 600 600])
hold on
% Display the 4 roots...
plot(1,0,'.m','Markersize',35)
plot(0,1,'.b','Markersize',35)
plot(-1,0,'.r','Markersize',35)
plot(0,-1,'.g','Markersize',35)
title('Click on Square to Continue','fontsize',18)
[x,y] = ginput(1);
z0 = x + i*y;
while abs(x-xc)<=r && abs(y-yc)<=r
    % Apply Newton..
    [root,zVals] = Newton(z0,MaxSteps);
    % and display the iterates...
    if root==1
        % Converges to the root z = 1
        h = plot(real(zVals),imag(zVals),'.m','Markersize',20);
        xlabel(sprintf('Number of Steps = %1d',length(zVals)),'fontsize',16)
    elseif root==2
        % Converges to the root z = i
        h = plot(real(zVals),imag(zVals),'.b','Markersize',20);
        xlabel(sprintf('Number of Steps = %1d',length(zVals)),'fontsize',16)
    elseif root==3
        % Converges to the root z = -1
        h = plot(real(zVals),imag(zVals),'.r','Markersize',20);
        xlabel(sprintf('Number of Steps = %1d',length(zVals)),'fontsize',16)
    elseif root==4
        % Converges to the root z = -i
        h = plot(real(zVals),imag(zVals),'.g','Markersize',20);
        xlabel(sprintf('Number of Steps = %1d',length(zVals)),'fontsize',16)
    else
        % More than MaxSteps required.
        h = plot(real(zVals),imag(zVals),'.w','Markersize',20);
        xlabel(sprintf('Required more than %1d steps',MaxSteps),'fontsize',16)
    end
    axis([xc-r xc+r yc-r yc+r])
    % Solicit the next starting point...
    [x,y] = ginput(1);
    z0 = x + i*y;
    delete(h)
end

  function [root,zVals] = Newton(z0,MaxSteps)
% Uses Newton's method to find a zero of f(z) = z^4-1.
% root = 0 if no convergence after 20 steps
% root = 1 if converges to 1
% root = 2 if converges to i
% root = 3 if converges to -1
% root = 4 if converges to -i
% zVals is a column vector of the (complex) iterates

dMin = inf;
z = z0;
zVals = z0;
steps = 0;
% Can show that if z is within .2 of a root, then Newton's method conversges
% to that root.
while dMin>=.2 && steps<MaxSteps
   z = z - (z^4 - 1)/(4*z^3);
   [dMin,root] = min(abs(z-[1 i -1 -i])); 
   zVals = [zVals ; z];
   steps = steps+1;
end
if steps==MaxSteps
    root = 0;
end