  function MakeNF2()
% Displays the Newton fractal associated with f(z) = z^4 -1;
% Number of displayed trajectories..
nTrajectories = 5000;
i = sqrt(-1);
close all
figure
% Maximum number of Newton steps...
MaxSteps = 50;
% The display area has center (xc,yc) and side length 2R
xc = 0; yc = 0; r = 1.2;
axis([xc-r xc+r yc-r yc+r])
fill([xc-r xc+r xc+r xc-r],[yc-r yc-r yc+r yc+r],'k')
hold on
% Display the 45 degree lines...
plot([xc-r xc+r],[yc-r yc+r],'w',[xc-r xc+r],[yc+r yc-r],'w');
axis square 
set(gcf,'position',[100 100 600 600])
hold on
% Display the 4 roots...
plot(1,0,'.y','Markersize',35)
plot(0,1,'.b','Markersize',35)
plot(-1,0,'.r','Markersize',35)
plot(0,-1,'.g','Markersize',35)
% 
for k=1:nTrajectories
    % Pick a random starting point and apply Newton..
    x0 = xc+r*(-1+2*rand(1));
    y0 = xc+r*(-1+2*rand(1));
    z0 = x0 + i*y0;
    [root,zVals] = Newton(z0,MaxSteps);
    % and display the iterates...
    if root==1
        % Converges to the root z = 1
        plot(real(zVals),imag(zVals),'.y','Markersize',5);
    elseif root==2
        % Converges to the root z = i
        plot(real(zVals),imag(zVals),'.b','Markersize',5);
    elseif root==3
        % Converges to the root z = -1
        plot(real(zVals),imag(zVals),'.r','Markersize',5);
    elseif root==4
        % Converges to the root z = -i
        plot(real(zVals),imag(zVals),'.g','Markersize',5);
    end
    axis([xc-r xc+r yc-r yc+r])
    shg
    if rem(k,100)==0
        title(sprintf('Number of Trajectories = %1d',k),'fontsize',16)
    end
end

  function [root,zVals] = Newton(z0,MaxSteps)
% Uses Newton's method to find a zero of f(z) = z^4-1.
% root = 0 if no convergence after 20 steps
% root = 1 if converges to 1
% root = 2 if converges to i
% root = 3 if converges to -1
% root = 4 if converges to -i
% zVals is a column vector of the (complex) iterates

dMin = inf;
z = z0;
zVals = z0;
steps = 0;
% Can show that if z is within .2 of a root, then Newton's method conversges
% to that root.
while dMin>=.2 && steps<MaxSteps
   z = z - (z^4 - 1)/(4*z^3);
   [dMin,root] = min(abs(z-[1 i -1 -i])); 
   zVals = [zVals ; z];
   steps = steps+1;
end
if steps==MaxSteps
    root = 0;
end